@@ -10,11 +10,8 @@ if [ -f /etc/mythtv/session-settings ]; then
     . /etc/mythtv/session-settings
 fi
 
-#Mythbuntu live configuration
-if [ -x /usr/bin/mythbuntu-startup ]; then
-    gksudo -k "mythbuntu-startup --load"
-#Mythbuntu normal session
-else
+#Don't process me if in live mode
+if [ ! -x /usr/bin/mythbuntu-startup ]; then
     #if nvidia settings are saved and nvidia drivers installed, load them
     if [ -x /usr/bin/nvidia-settings ] && [ -f ~/.nvidia-settings-rc ]; then
         nvidia-settings -l
@@ -38,7 +35,7 @@ else
     if [ -x /usr/bin/x11vnc ]; then
         [ -f /root/.vnc/passwd ] && PASSWORD="/root/.vnc/passwd"
         [ -f $HOME/.vnc/passwd ] && PASSWORD="$HOME/.vnc/passwd"
-        [ ! -z "$PASSWORD" ] && x11vnc -rfbauth $PASSWORD -rfbport 5900 -shared -forever -nowf -norc -notruecolor -bg
+        [ ! -z "$PASSWORD" ] && x11vnc -rfbauth $PASSWORD -rfbport 5900 -shared -forever -nowf -norc -notruecolor -bg -xkb
     fi
     #Customized home commands
     if [ -x $HOME/.mythtv/session ]; then
@@ -47,6 +44,6 @@ else
 fi
 
 #Start window manager
-export XDG_CONFIG_DIRS=/etc/xdg/mythbuntu
-export XDG_DATA_DIRS=/etc/xdg/mythbuntu
+export XDG_CONFIG_DIRS=/etc/xdg/xdg-mythbuntu
+export XDG_DATA_DIRS=/etc/xdg/xdg-mythbuntu
 exec startxfce4
